moviepy.video.fx.all.loop — MoviePy 1.0.1 documentation

# moviepy.video.fx.all.loop

`moviepy.video.fx.all.` `loop`(self, n=None, duration=None)

  Returns a clip that plays the current clip in an infinite loop. Ideal for clips coming from gifs.

  Parameters
    n

      Number of times the clip should be played. If None the the clip will loop indefinitely (i.e. with no set duration).

    duration

      Total duration of the clip. Can be specified instead of n.